@@ -333,7 +333,7 @@ Ext.define('MP.data.MetaData', {
                 column.sortable = info.sortable;
             }
 
-            if(!readonly && editors) {
+            if(!readonly && editors && info.name in editors) {
                 column.editor = editors[info.name];
                 column.editor.fieldLabel = null;
             }
